@@ -39,6 +39,8 @@ askgpt <- function(prompt,
   }
 
   callfun <- ifelse(chat, chat_api, completions_api)
+  # api function can be replaced with random function (for testing)
+  if ("callfun" %in% names(list(...))) callfun <- list(...)$callfun
 
   if (progress) {
 
@@ -75,6 +77,7 @@ askgpt <- function(prompt,
   if (return_answer) {
     return(out)
   } else {
+    screen_answer(out)
     invisible(response)
   }
 }
